@@ -1,14 +1,14 @@
-# $Id: Backup.pm,v 1.21 2003/09/22 00:58:19 gene Exp $
+# $Id: Backup.pm,v 1.24 2003/09/26 16:45:10 gene Exp $
 
 package File::Backup;
-
 use strict;
-use Carp;
-use vars qw($VERSION @EXPORT_OK @EXPORT);
-use base qw(Exporter);
-@EXPORT = @EXPORT_OK = qw(backup);
-$VERSION = '0.06';
 
+use base qw(Exporter);
+use vars qw($VERSION @EXPORT_OK @EXPORT);
+@EXPORT = @EXPORT_OK = qw(backup);
+$VERSION = '0.0602';
+
+use Carp;
 use Cwd;
 use File::Which;
 use LockFile::Simple qw(lock unlock);
@@ -25,6 +25,7 @@ sub backup {  # {{{
 
 # TODO Implement these:
 #        files => [],    # List of files to backup.
+#        individual => 0,  # Archive files one at a time, not as a bundle.
 #        include => '',  # Regular expression of filenames to match.
 #        exclude => '',  # Regular expression of filenames to match.
 #        flatten => 0,   # Do not preserve the source directory tree.
@@ -259,7 +260,8 @@ your computer is okay with that... Cross platform file backing is
 going to be implemented soon.
 
 A really nice feature of this new version is the use of C<File::Which> 
-to find your local version of tar and gzip.
+to find your local version of tar and gzip.  Additionally, automatic
+file locking ala C<LockFile::Simple> is implemented now.
 
 One very cool thing is that you can now supply the C<backup> function 
 with an arbitrary timestamp format string.
@@ -282,14 +284,20 @@ and a destination directory, and puts a compressed archive file of the
 source directory files into the destination directory.
 
 Return a hash reference with the path of the source as key and the 
-name of the archive file as the value or the files that were backed-up 
-individually as the keys and the new, timestamped path names as their 
-values, respectively.
+name of the archive file as the value.
+
+* When the list of files to back is implemented (see C<TO DO>), these 
+files will be the keys and the new, timestamped path names of the 
+backed as their values.
 
 The function arguments are described below.
 
 =over 4
 
+=item * debug => 0 | 1
+
+Turn on verbose processing.  Defaults to zero (off).
+
 =item * from => $PATH
 
 The source directory of files to backup.  If not given, the current 
@@ -327,24 +335,28 @@ combination of the following in order:
 How about some examples:
 
 'YYYY-MM-DD_hh-mm-ss' is seen by C<sprintf> as
-'%4d-%02d-%02d_%02d-%02d-%02d'.  For September 11, 2003 at 8:23 and 
-47 seconds AM, that would be '2003-09-11_08-23-47'.
+'%4d-%02d-%02d_%02d-%02d-%02d'.  For Janurary 2, 2003 at 3:04 and 
+5 seconds AM, that would be '2003-01-02_03-04-05'.
 
-'YYMMDDhhmmss' would be '%02d%02d%02d%02d%02d%02d' producing 
-'030911082347'. 
+You can leave off ending format characters.  'YYYYMMDD' would be 
+'%04d%02d%02d' producing '20030102'.
 
-You can leave off format ending format characters to.  So 'YYMMDD' 
-would be '%02d%02d%02d' producing '20030911'.
+Note that this module always uses a four digit numeral for the year,
+so 'Y-MMDD' will produce '2003-0102'. 
 
 This "reverse date" scheme is used to unambiguously sort the backup 
 files chronologially.  That is, the stamp must be in order of largest 
-timescale maginitude.  Of course, you can producing an ambiguous stamp
-with 'YMD-hms', which would be '%01d%01d%01d-%01d%01d%01d' producing 
-'2003911-82347'.
+timescale maginitude.  Of course, you can produce an ambiguous stamp
+with 'YMDhms' which would produce '200312345'.  Is this December 3rd,
+2003?  Who knows?
 
 =item * archive => 0 | 1
 
-Flag to archive (with tar/gz/zip) the backed-up files.  Default 1.
+Flag to archive the backed-up files.  Default 1.
+
+* This is not useful yet, but in a future version files will be able 
+to be stamped and copied to a backup directory without any bundled 
+archiving.
 
 =item * archiver => $PATH_TO_PROGRAM
 
@@ -373,12 +385,15 @@ The compression program.  Default is your local gzip.
 
 =item * compress_flags => $COMMAND_SWITCHES
 
-The optional compression switches.
+The optional compression switches.  Default is off (i.e. set to 
+nothing).
 
 =item * compress => 0 | 1
 
 Flag to turn archive compression off or on.
 
+* Currently, this only makes sense if the C<archive> flag is turned on.
+
 =item * files => \@FILENAMES
 
 The optional list of files to backup.
@@ -525,6 +540,8 @@ L<Cwd>
 
 L<File::Which>
 
+L<LockFile::Simple>
+
 =head1 THANK YOU
 
 Help, insight, suggestions and comments came from Ken Williams
